"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.connect = void 0;
const tslib_1 = require("tslib");
const ioredis_1 = tslib_1.__importDefault(require("ioredis"));
const generateKey_1 = require("./generateKey");
async function connect(connection, scopes) {
    const { uri, database, clientOpts } = connection;
    const keys = [clientOpts === null || clientOpts === void 0 ? void 0 : clientOpts.keyPrefix, database].concat(scopes);
    const keyPrefix = generateKey_1.generateKey(keys, true);
    const options = Object.assign(Object.assign({}, clientOpts), { keyPrefix });
    const redis = new ioredis_1.default(uri, options);
    try {
        await redis.ping();
    }
    catch (e) {
        redis.disconnect();
        throw new Error("CONNECTION:REDIS.FAILED");
    }
    return redis;
}
exports.connect = connect;
